# Generic Views
#### nocton.generic.views

As views genéricas são formas ainda mais simplificadas das views genéricas presentes no django_rest_framework. A documentação dessas views foram divididas em duas partes, as ```Base_Generic_Views``` e as ```Generic_Views``` propriamente ditas.

- [Views genéricas bases](views/base_generic_views.md#Base_Generic_Views)
- [Views genéricas finais](views/real_generic_views.md#Generic_Views)